@@ -543,8 +543,7 @@ public:
   unsigned int GetLastWriteIndex() const;
   uint64_t GetLastEventId() const;
   double GetFPS() const;
-  void UpdateAnalysisFPS();
-  void UpdateCaptureFPS();
+  void UpdateFPS();
   void ForceAlarmOn( int force_score, const char *force_case, const char *force_text="" );
   void ForceAlarmOff();
   void CancelForced();
@@ -583,6 +582,10 @@ public:
   bool Decode();
   void DumpImage( Image *dump_image ) const;
   void TimestampImage(Image *ts_image, const timeval &ts_time) const;
+  Event * openEvent(
+    const std::shared_ptr<ZMPacket> &snap,
+    const std::string &cause,
+    const Event::StringSetMap &noteSetMap);
   void closeEvent();
 
   void Reload();
