@@ -388,7 +388,7 @@ bool MonitorStream::sendFrame(Image *image, const timeval &timestamp) {
   if ( type == STREAM_MPEG ) {
     if ( !vid_stream ) {
       vid_stream = new VideoStream("pipe:", format, bitrate, effective_fps, send_image->Colours(), send_image->SubpixelOrder(), send_image->Width(), send_image->Height());
-      fprintf(stdout, "Content-type: %s\r\n\r\n", vid_stream->MimeType());
+      fprintf(stdout, "Content-Type: %s\r\n\r\n", vid_stream->MimeType());
       vid_stream->OpenStream();
     }
     static struct timeval base_time;
@@ -479,24 +479,6 @@ void MonitorStream::runStream() {
   if (type == STREAM_JPEG)
     fputs("Content-Type: multipart/x-mixed-replace; boundary=" BOUNDARY "\r\n\r\n", stdout);
 
-  /* This is all about waiting and showing a useful message if the monitor isn't available */
-  while (!zm_terminate) {
-    if (connkey)
-      checkCommandQueue();
-
-    if (!checkInitialised()) {
-      if (!loadMonitor(monitor_id)) {
-        if (!sendTextFrame("Not connected")) return;
-      } else {
-        if (!sendTextFrame("Unable to stream")) return;
-      }
-      sleep(1);
-    } else {
-      break;
-    }
-  }
-  if (zm_terminate) return;
-
   updateFrameRate(monitor->GetFPS());
 
   // point to end which is theoretically not a valid value because all indexes are % image_buffer_count
@@ -568,9 +550,6 @@ void MonitorStream::runStream() {
     } else if (ferror(stdout)) {
       Debug(2, "ferror stdout");
       break;
-    } else if (!monitor->ShmValid()) {
-      Debug(2, "monitor not valid.... maybe we should wait until it comes back.");
-      break;
     }
 
     gettimeofday(&now, nullptr);
@@ -583,12 +562,28 @@ void MonitorStream::runStream() {
         Debug(2, "Have checking command Queue for connkey: %d", connkey);
         got_command = true;
       }
+      if (zm_terminate) break;
       // Update modified time of the socket .lock file so that we can tell which ones are stale.
       if ( now.tv_sec - last_comm_update.tv_sec > 3600 ) {
         touch(sock_path_lock);
         last_comm_update = now;
       }
     }  // end if connkey
+    if (!checkInitialised()) {
+      if (!loadMonitor(monitor_id)) {
+        if (!sendTextFrame("Not connected")) {
+          Debug(1, "Failed Send not connected");
+          continue;
+        }
+      } else {
+        if (!sendTextFrame("Unable to stream")) {
+          Debug(1, "Failed Send unable to stream");
+          return;
+        }
+      }
+      usleep(MonitorStream::MAX_SLEEP_USEC);
+      continue;
+    }
 
     if (paused) {
       if (!was_paused) {
@@ -849,6 +844,8 @@ void MonitorStream::runStream() {
       }
     } // end if checking for swap_path
   } // end if buffered_playback
+  if (zm_terminate)
+    Debug(1, "zm_terminate");
 
   closeComms();
 } // end MonitorStream::runStream
