@@ -140,7 +140,7 @@ bool VideoStore::open() {
 
   oc->metadata = pmetadata;
   out_format = oc->oformat;
-  oc->oformat->flags |= AVFMT_TS_NONSTRICT; // allow non increasing dts
+  //oc->oformat->flags |= AVFMT_TS_NONSTRICT; // allow non increasing dts
 
   if (video_in_stream) {
 #if LIBAVCODEC_VERSION_CHECK(57, 64, 0, 64, 0)
@@ -349,6 +349,8 @@ bool VideoStore::open() {
 #else
   avcodec_copy_context(video_out_stream->codec, video_out_ctx);
 #endif
+  last_dts[video_out_stream->index] = AV_NOPTS_VALUE;
+
   video_out_stream->time_base = video_in_stream ? video_in_stream->time_base : AV_TIME_BASE_Q;
   if (monitor->GetOptVideoWriter() == Monitor::PASSTHROUGH) {
     // Only set orientation if doing passthrough, otherwise the frame image will be rotated
@@ -470,6 +472,7 @@ bool VideoStore::open() {
 
     // We will assume that subsequent stream allocations will increase the index
     max_stream_index = audio_out_stream->index;
+    last_dts[audio_out_stream->index] = AV_NOPTS_VALUE;
   }  // end if audio_in_stream
 
   //max_stream_index is 0-based, so add 1
@@ -1238,9 +1241,9 @@ int VideoStore::writeAudioFramePacket(const std::shared_ptr<ZMPacket> &zm_packet
   if (!audio_first_dts) {
     audio_first_dts = ipkt->dts;
     audio_next_pts = audio_out_ctx->frame_size;
+    Debug(3, "audio first_dts to %" PRId64, audio_first_dts);
   }
 
-  Debug(3, "audio first_dts to %" PRId64, audio_first_dts);
   // Need to adjust pts before feeding to decoder.... should really copy the pkt instead of modifying it
 
   if (audio_out_codec) {
@@ -1313,25 +1316,34 @@ int VideoStore::write_packet(AVPacket *pkt, AVStream *stream) {
   pkt->stream_index = stream->index;
 
   if (pkt->dts == AV_NOPTS_VALUE) {
-    Debug(1, "undef dts, fixing by setting to stream cur_dts %" PRId64, stream->cur_dts);
-    pkt->dts = stream->cur_dts;
-  } else if (pkt->dts < stream->cur_dts) {
-    Debug(1, "non increasing dts, fixing. our dts %" PRId64 " stream cur_dts %" PRId64, pkt->dts, stream->cur_dts);
-    pkt->dts = stream->cur_dts;
+    if (last_dts[stream->index] == AV_NOPTS_VALUE) {
+      last_dts[stream->index] = 0;
+    } 
+    pkt->dts = last_dts[stream->index];
+  } else if (pkt->dts < last_dts[stream->index]) {
+    Warning("non increasing dts, fixing. our dts %" PRId64 " stream %d last_dts %" PRId64,
+        pkt->dts, stream->index, last_dts[stream->index]);
+    pkt->dts = last_dts[stream->index];
   }
 
-  if (pkt->dts > pkt->pts) {
-    Debug(1,
+  if (pkt->pts == AV_NOPTS_VALUE) {
+    pkt->pts = pkt->dts;
+  } else if (pkt->dts > pkt->pts) {
+    Warning("pkt.dts(%" PRId64 ") must be <= pkt.pts(%" PRId64 ")."
+            "Decompression must happen before presentation.",
+            pkt->dts, pkt->pts);
+/*    Debug(1,
           "pkt.dts(%" PRId64 ") must be <= pkt.pts(%" PRId64 ")."
           "Decompression must happen before presentation.",
-          pkt->dts, pkt->pts);
+          pkt->dts, pkt->pts);*/
     pkt->pts = pkt->dts;
   }
 
   ZM_DUMP_STREAM_PACKET(stream, (*pkt), "finished pkt");
   next_dts[stream->index] = pkt->dts + pkt->duration;
-  Debug(3, "next_dts for stream %d has become %" PRId64,
-      stream->index, next_dts[stream->index]);
+  last_dts[stream->index] = pkt->dts;
+  Debug(3, "next_dts for stream %d has become %" PRId64 " last_dts %" PRId64,
+      stream->index, next_dts[stream->index], last_dts[stream->index]);
 
   int ret = av_interleaved_write_frame(oc, pkt);
   if (ret != 0) {
