@@ -88,7 +88,7 @@ fi;
 
 if [ "$DISTROS" == "" ]; then
   if [ "$RELEASE" != "" ]; then
-    DISTROS="xenial,bionic,focal,hirsute,impish"
+    DISTROS="xenial,bionic,focal,hirsute,impish,jammy"
   else
     DISTROS=`lsb_release -a 2>/dev/null | grep Codename | awk '{print $2}'`;
   fi;
@@ -258,13 +258,13 @@ IFS=',' ;for DISTRO in `echo "$DISTROS"`; do
   fi;
 
   # Generate Changlog
-  if [ "$DISTRO" == "focal" ] || [ "$DISTRO" == "buster" ] || [ "$DISTRO" == "hirsute" ] || [ "$DISTRO" == "impish" ]; then 
-    cp -Rpd distros/ubuntu2004 debian
+  if [ "$DISTRO" == "xenial" ] || [ "$DISTRO" == "stretch" ]; then
+    cp -Rpd distros/ubuntu1604 debian
   elif [ "$DISTRO" == "beowulf" ]
   then
     cp -Rpd distros/beowulf debian
   else
-    cp -Rpd distros/ubuntu1604 debian
+    cp -Rpd distros/ubuntu2004 debian
   fi;
 
   if [ "$DEBEMAIL" != "" ] && [ "$DEBFULLNAME" != "" ]; then
