@@ -115,8 +115,12 @@ xhtmlHeaders(__FILE__, translate('Frame').' - '.$Event->Id().' - '.$Frame->Frame
       <div>
         <p id="image">
 <?php
-if ( $imageData['hasAnalImage'] ) {
-  echo sprintf('<a href="?view=frame&amp;eid=%d&amp;fid=%d&scale=%d&amp;show=%s">', $Event->Id(), $Frame->FrameId(), $scale, ( $show=='anal'?'capt':'anal' ) );
+if ($imageData['hasAnalImage']) {
+  echo sprintf('<a href="?view=frame&amp;eid=%d&amp;fid=%d&scale=%d&amp;show=%s" title="Click to display frame %s analysis">',
+    $Event->Id(), $Frame->FrameId(), $scale,
+    ($show=='anal'?'capt':'anal'),
+    ($show=='anal'?'without':'with')
+  );
 }
 ?>
 <img id="frameImg"
@@ -125,6 +129,7 @@ if ( $imageData['hasAnalImage'] ) {
   height="<?php echo reScale($Event->Height(), $Monitor->DefaultScale(), $scale) ?>"
   alt="<?php echo $Frame->EventId().'-'.$Frame->FrameId() ?>"
   class="<?php echo $imageData['imageClass'] ?>"
+  loading="lazy"
 />
 <?php
 if ($imageData['hasAnalImage']) { ?></a><?php } ?>
