@@ -46,8 +46,14 @@ rtspStreamNames[\''.validJsStr($row['RTSPStreamName']).'\'] = true;
 function validateForm( form ) {
   var errors = new Array();
   var warnings = new Array();
+  const elements = form.elements;
 
-  if ( form.elements['newMonitor[Name]'].value.search( /[^\w\-\.\(\)\:\/ ]/ ) >= 0 )
+  // No monitor input should have whitespace at beginning or end, so strip them out first.
+  for (var i=0; i<elements.length; i++) {
+    elements[i].value = elements[i].value.trim();
+  }
+
+  if ( elements['newMonitor[Name]'].value.search( /[^\w\-\.\(\)\:\/ ]/ ) >= 0 )
     errors[errors.length] = "<?php echo translate('BadNameChars') ?>";
   else if ( monitorNames[form.elements['newMonitor[Name]'].value] )
     errors[errors.length] = "<?php echo translate('DuplicateMonitorName') ?>";
@@ -78,6 +84,10 @@ function validateForm( form ) {
     } else if (form.elements['newMonitor[Path]'].value.match(/[\!\*'\(\)\$ ,#]/)) {
       warnings[warnings.length] = "<?php echo translate('BadPathNotEncoded') ?>";
     }
+    let url = new URL(form.elements['newMonitor[Path]'].value);
+    if (url.href != form.elements['newMonitor[Path]'].value) {
+      warnings[warnings.length] = "<?php echo translate('BadPathNotEncoded') ?>";
+    }
 
   } else if ( form.elements['newMonitor[Type]'].value == 'File' ) {
     if ( !form.elements['newMonitor[Path]'].value )
