@@ -42,7 +42,7 @@ function selectLayout(element) {
     if (layouts[layout_id].Name != 'Freeform') { // 'montage_freeform.css' ) {
       // For freeform, we don't touch the width/height/scale settings, but we may need to update sizing and scales
       setCookie('zmMontageScale', '', 3600);
-      $j('#scale').val('');
+      $j('#scale').val('0');
       $j('#width').val('0');
     }
   } // end if a stored layout
@@ -58,12 +58,12 @@ function selectLayout(element) {
     var monitor = monitors[i];
 
     var stream_scale = 0;
-    if (scale) {
+    if (parseInt(scale) > 0) {
       stream_scale = scale;
     } else if (width) {
-      stream_scale = parseInt(100*width/monitor.width);
+      stream_scale = parseInt(100*parseInt(width)/monitor.width);
     } else if (height) {
-      stream_scale = parseInt(100*height/monitor.height);
+      stream_scale = parseInt(100*parseInt(height)/monitor.height);
     } else if (layouts[layout_id].Name != 'Freeform') {
       monitor_frame = $j('#monitorFrame'+monitor.id);
       console.log("Monitor frame width : " + monitor_frame.width() + " monitor Width: " + monitor.width);
@@ -73,36 +73,34 @@ function selectLayout(element) {
         stream_scale = Math.floor(stream_scale/5)*5;
       }
     }
-    setStreamScale('liveStream'+monitor.id, stream_scale, width, height);
+    monitor.setStreamScale(stream_scale);
   } // end foreach monitor
 } // end function selectLayout(element)
 
-function setStreamScale(element_id, scale, width, height) {
-  var streamImg = document.getElementById(element_id);
-  if (streamImg) {
-    if (streamImg.nodeName == 'IMG') {
-      var src = streamImg.src;
-      src = src.replace(/scale=\d*/i, 'scale='+scale);
-      if (height == '0') {
-        streamImg.style.height = 'auto';
-      }
-      if (src != streamImg.src) {
-        streamImg.src = '';
-        streamImg.src = src;
-      }
-    } else if (streamImg.nodeName == 'APPLET' || streamImg.nodeName == 'OBJECT') {
-      // APPLET's and OBJECTS need to be re-initialized
-    }
-    //streamImg.style.width = '100%';
+function changeHeight() {
+  var height = $j('#height').val();
+  setCookie('zmMontageHeight', height, 3600);
+  for (var i = 0, length = monitors.length; i < length; i++) {
+    var monitor = monitors[i];
+    monitor_frame = $j('#monitor'+monitor.id + " .monitorStream");
+    monitor_frame.css('height', height);
+    monitor_img = $j('#liveStream'+monitor.id);
+    monitor_img.css('height', parseInt(height) ? height+'px' : 'auto');
   }
 }
 
 /**
- * called when the widthControl|heightControl select elements are changed
+ * called when the widthControl select elements are changed
  */
-function changeSize() {
+function changeWidth() {
   var width = parseInt($j('#width').val());
   var height = parseInt($j('#height').val());
+  $j('#width').val(width);
+  $j('#height').val(height);
+
+  // Reset frame css
+  $j('#zmMontageLayout').val(freeform_layout_id);
+  selectLayout();
 
   for ( var i = 0, length = monitors.length; i < length; i++ ) {
     var monitor = monitors[i];
@@ -115,32 +113,19 @@ function changeSize() {
     }
     monitor_frame.css('width', ( width ? width+'px' : 'auto'));
     monitor_frame.css('height', ( height ? height+'px' : 'auto'));
-
-    /*Stream could be an applet so can't use moo tools*/
-    var streamImg = document.getElementById('liveStream'+monitor.id);
-    if ( streamImg ) {
-      if ( streamImg.nodeName == 'IMG' ) {
-        var src = streamImg.src;
-        streamImg.src = '';
-        var scale = 100;
-        if ( width ) {
-          scale = parseInt(100*width/monitor.width);
-        } else if ( height ) {
-          scale = parseInt(100*height/monitor.height);
-        }
-        // Note zms ignores width and height
-        src = src.replace(/scale=\d*/i, 'scale='+scale);
-
-        src = src.replace(/rand=\d+/i, 'rand='+Math.floor((Math.random() * 1000000) ));
-        streamImg.src = src;
-      }
-      streamImg.style.width = width ? width+'px' : null;
-      streamImg.style.height = height ? height+'px' : null;
-      //streamImg.style.height = '';
+    var scale = 100;
+    if ( width ) {
+      scale = parseInt(100*width/monitor.width);
+    } else if ( height ) {
+      scale = parseInt(100*height/monitor.height);
     }
-  }
-  $j('#scale').val('');
-  setCookie('zmMontageScale', '', 3600);
+    monitor_img = $j('#liveStream'+monitor.id);
+    monitor_img.css('width', parseInt(width) ? width+'px' : 'auto');
+
+    monitor.setStreamScale(scale);
+  } // end foreach monitor
+  $j('#scale').val('0');
+  setCookie('zmMontageScale', '0', 3600);
   setCookie('zmMontageWidth', width, 3600);
   setCookie('zmMontageHeight', height, 3600);
   $j("#zmMontageLayout option:selected").removeAttr("selected");
@@ -157,14 +142,10 @@ function changeScale() {
   setCookie('zmMontageScale', scale, 3600);
   setCookie('zmMontageWidth', '', 3600);
   setCookie('zmMontageHeight', '', 3600);
-  if ( scale == '' ) {
-    selectLayout('#zmMontageLayout');
-    return;
-  }
-  for ( var i = 0, length = monitors.length; i < length; i++ ) {
-    var monitor = monitors[i];
-    var newWidth = ( monitorData[i].width * scale ) / SCALE_BASE;
-    var newHeight = ( monitorData[i].height * scale ) / SCALE_BASE;
+  $j('#zmMontageLayout').val(freeform_layout_id);
+  selectLayout('#zmMontageLayout');
+  for ( let i = 0, length = monitors.length; i < length; i++ ) {
+    const monitor = monitors[i];
 
     // Scale the frame
     monitor_frame = $j('#monitorFrame'+monitor.id);
@@ -173,39 +154,16 @@ function changeScale() {
       continue;
     }
     if ( scale != '0' ) {
+      const newWidth = ( monitorData[i].width * scale ) / SCALE_BASE;
       if ( newWidth ) {
+        console.log("Setting to " + newWidth);
         monitor_frame.css('width', newWidth);
       }
-    } else {
-      monitor_frame.css('width', '100%');
     }
-    // We don't set the frame height because it has the status bar as well
-    //if ( height ) {
-    ////monitor_frame.css('height', height+'px');
-    //}
-    /*Stream could be an applet so can't use moo tools*/
-    var streamImg = $j('#liveStream'+monitor.id)[0];
-    if ( streamImg ) {
-      if ( streamImg.nodeName == 'IMG' ) {
-        var src = streamImg.src;
-        streamImg.src = '';
-
-        //src = src.replace(/rand=\d+/i,'rand='+Math.floor((Math.random() * 1000000) ));
-        if ( scale != '0' ) {
-          src = src.replace(/scale=[\.\d]+/i, 'scale='+scale);
-        } else {
-          src = src.replace(/scale=[\.\d]+/i, 'scale=100');
-        }
-        streamImg.src = src;
-      }
-      if ( scale != '0' ) {
-        streamImg.style.width = newWidth + 'px';
-        streamImg.style.height = newHeight + 'px';
-      } else {
-        streamImg.style.width = '100%';
-        streamImg.style.height = 'auto';
-      }
-    } // end if StreamImg
+    monitor_img = $j('#liveStream'+monitor.id);
+    monitor_img.css('width', '100%');
+    monitor_img.css('height', 'auto');
+    monitor.setStreamScale(scale);
   } // end foreach Monitor
 }
 
